@@ -1,13 +1,13 @@
 package Complete::Env;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Complete::Setting;
+use Complete::Common qw(:all);
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -33,9 +33,6 @@ use case-insensitive option (`ci`) to match against original casing.
 _
     args => {
         word     => { schema=>[str=>{default=>''}], pos=>0, req=>1 },
-        ci       => { schema=>['bool'] },
-        fuzzy    => { schema=>['int*', min=>0] },
-        map_case => { schema=>['bool'] },
     },
     result_naked => 1,
     result => {
@@ -47,17 +44,14 @@ sub complete_env {
 
     my %args  = @_;
     my $word     = $args{word} // "";
-    my $ci       = $args{ci} // $Complete::Setting::OPT_CI;
-    my $fuzzy    = $args{fuzzy} // $Complete::Setting::OPT_FUZZY;
-    my $map_case = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
     if ($word =~ /^\$/) {
         Complete::Util::complete_array_elem(
             word=>$word, array=>[map {"\$$_"} keys %ENV],
-            ci=>$ci, fuzzy=>$fuzzy, map_case=>$map_case);
+        );
     } else {
         Complete::Util::complete_array_elem(
             word=>$word, array=>[keys %ENV],
-            ci=>$ci, fuzzy=>$fuzzy, map_case=>$map_case);
+        );
     }
 }
 1;
@@ -75,7 +69,7 @@ Complete::Env - Completion routines related to environment variables
 
 =head1 VERSION
 
-This document describes version 0.37 of Complete::Env (from Perl distribution Complete-Env), released on 2015-09-17.
+This document describes version 0.38 of Complete::Env (from Perl distribution Complete-Env), released on 2015-11-29.
 
 =head1 DESCRIPTION
 
@@ -89,16 +83,12 @@ Complete from environment variables.
 On Windows, environment variable names are all converted to uppercase. You can
 use case-insensitive option (C<ci>) to match against original casing.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
-=item * B<fuzzy> => I<int>
-
-=item * B<map_case> => I<bool>
-
 =item * B<word>* => I<str> (default: "")
 
 =back
